@@ -70,7 +70,7 @@ main (int   argc,
   guint order = 0;
 
   shift_argc = argc;
-  shift_argv = argv;
+  shift_argv = (gchar **)argv;
 
   if (!g_thread_supported ())
       g_thread_init (NULL);
