@@ -418,7 +418,7 @@ PlayObject SimpleSoundServer_impl::createPlayObject(const string& filename)
 	/*
 	 * create a PlayObject and connect it
 	 */
-	if(objectType != "")
+	if(!objectType.empty())
 	{
 		arts_debug("creating %s to play file %s", objectType.c_str(), filename.c_str() );
 
